API Documentation
================

Main Pipeline
------------

.. automodule:: nabqr.nabqr
   :members:
   :undoc-members:
   :show-inheritance:

Core Functions
-------------

.. automodule:: nabqr.functions
   :members:
   :undoc-members:
   :show-inheritance:

TAQR Implementation
------------------

.. automodule:: nabqr.functions_for_taqr
   :members:
   :undoc-members:
   :show-inheritance:

Helper Functions
--------------

.. automodule:: nabqr.helper_functions
   :members:
   :undoc-members:
   :show-inheritance:

Visualization
------------

.. automodule:: nabqr.visualization
   :members:
   :undoc-members:
   :show-inheritance:

Package Contents
--------------

.. automodule:: nabqr
   :members:
   :undoc-members:
   :show-inheritance: 